#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import re

import config
import html5out as htmlout

from os.path   import walk, basename, join, exists
from datetime  import datetime

##############################################################################
#
# global variables
#
##############################################################################

# database with active days per month
daydb    = [ [], [], [], [], [], [], [], [], [], [], [], [], [] ]

# regular expression to locate ISO date names (without year)
date_re  = re.compile( '([0-9]{2})-([0-9]{2})' )

# regular expression for month-only directories
month_re = re.compile( '([0-9]{2})' )

# regular expression for years
year_re  = re.compile( '([12][0-9]{3})' )

##############################################################################
#
# local functions
#
##############################################################################

#
# insert days in local directory into database
#
def visitdir ( arg, dirname, names ):
    dir = basename( dirname )
    m   = date_re.search( dir )
    if m != None:
        month = int( m.group( 1 ) )
        day   = int( m.group( 2 ) )

        try:
            daydb[month].append( day )
        except:
            daydb[month] = [ day ]
    else:
        # filter out year directories
        m = year_re.search( dir )

        if m == None:
            m = month_re.search( dir )

            if m != None:
                month = int( m.group( 1 ) )
                
                # insert special tag indicating month-only dir
                try:
                    daydb[month].append( 'all' )
                except:
                    daydb[month] = [ 'all' ]
            

#
# write calender for a specifice year
#
def write_year ( year ):

    #
    # read in local directory structure based on "mm-dd"
    # and store all days for which album exists
    #

    walk( join( config.top_dir, str( year ) ), visitdir, None )

    #
    # generate index.xml with linked days
    #
    date    = datetime( year, 1, 1 )
    weekday = date.weekday()-1
    weeknr  = 1

    outfile = ''

    try:
        if config.out_type == 'xml':
            outfile = join( config.top_dir, str( year ), 'index.xml' )
            xmlout.write_year( outfile, year, daydb )
        elif config.out_type == 'html':
            outfile = join( config.top_dir, str( year ), 'index.html' )
            htmlout.write_year( outfile, year, daydb )
    except Exception, e:
        print '(genyear) error writing "' + outfile + '" : ' + str( e )
        sys.exit( 1 )

#
# return previous year w.r.t. argument if present
# - look for at most <max> years in difference
# - if not available, return <year>
#
def prev_year ( year, max = 100 ):

    for d in range( 1, max ):
        if exists( join( config.top_dir, str(year-d) ) ):
            return year-d

    return year

#
# same as prev_year but return next year
#
def next_year ( year, max = 100 ):

    for d in range( 1, max ):
        if exists( join( config.top_dir, str(year+d) ) ):
            return year+d

    return year

##############################################################################
#
# main program
#
##############################################################################

#
# read year from commandline
#

# def main ():
#     try:
#         year = int( sys.argv[1] )
#         write_year( year )
#     except IndexError:
#         print "usage: genyear <year>"
#         sys.exit( 1 )

# if __name__ == '__main__':
#     main()

## EOF ##
